"""python -m powrap entry point."""

__import__("powrap.powrap").powrap.main()
